import json
from typing import Optional
from foundationallm.config import UserIdentity

class Context:
    def __init__(self, user_identity: Optional[UserIdentity] = None):
        """Init"""
        if (user_identity is not None):
            self.user_identity = json.loads(user_identity,
                                        object_hook=UserIdentity.from_json) or None
        else:
            self.user_identity = None

    def get_upn(self) -> str:
        if (self.user_identity is not None):
            return self.user_identity.upn or ''
        else:
            return ''



"""
Class: IndexingProfileBase
Description: Base class for vectorization index profiles.
"""
from foundationallm.models.resource_providers.vectorization import ProfileBase

class IndexingProfileBase(ProfileBase):
    """
    Base class to hold indexing profile information.
    """
    indexer: str



from enum import Enum

class OperationTypes(str, Enum):
   """Enumerator of the Operation Types."""
   ASSISTANTS_API = "assistants_api"
   CHAT = "chat"
   COMPLETIONS = "completions"
   IMAGE_SERVICES = "image_services"
